parser

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package parser provides shared Go AST parsing utilities used by all analyzers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsExported

func IsExported(name string) bool

IsExported reports whether a name is exported.

func MatchesAny

func MatchesAny(relPath string, patterns []string) bool

MatchesAny checks if a relative path matches any of the given glob patterns.

func Parse

func Parse(rootDir string, cfg *analyzer.Config) (*analyzer.Project, error)

Parse parses all Go files in the given root directory.

func RelPath

func RelPath(rootDir, absPath string) string

RelPath returns the path relative to rootDir, using forward slashes.

Types

This section is empty.

Jump to